@@ -1311,22 +1311,25 @@ class Insight_Definition:
                 "role": "ADMIN",
                 "userId": r.json()[0]["id"]
             }
+            try:
+                url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
-            url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
+                s = requests.Session()
+                s.keep_alive = False
+                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+                s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            s = requests.Session()
-            s.keep_alive = False
-            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-            s.mount('https://', HTTPAdapter(max_retries=retries))
+                headers = {
+                    "Content-Type": "application/json",
+                    "Authorization": "Bearer" + " " + self._token
+                }
+                query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
+                #logging.info("URL {}".format(query_url))
+                r = s.post(url=url, json=body, headers=headers)
+                r.raise_for_status()
+            except:
+                logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(follower_email))
 
-            headers = {
-                "Content-Type": "application/json",
-                "Authorization": "Bearer" + " " + self._token
-            }
-            query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-            #logging.info("URL {}".format(query_url))
-            r = s.post(url=url, json=body, headers=headers)
-            r.raise_for_status()
         else:
             logging.error("EMAIL ERRATA: Inserire una email corrispondente ad un utente Askdata")
 
@@ -1352,22 +1355,25 @@ class Insight_Definition:
                 "role": "FOLLOWER",
                 "userId": r.json()[0]["id"]
             }
+            try:
+                url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
 
-            url = self.smart_insight_url+"/insights/"+self.definition_id+"/users"
+                s = requests.Session()
+                s.keep_alive = False
+                retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+                s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            s = requests.Session()
-            s.keep_alive = False
-            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-            s.mount('https://', HTTPAdapter(max_retries=retries))
+                headers = {
+                    "Content-Type": "application/json",
+                    "Authorization": "Bearer" + " " + self._token
+                }
+                query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
+                #logging.info("URL {}".format(query_url))
+                r = s.post(url=url, json=body, headers=headers)
+                r.raise_for_status()
+            except:
+                logging.info("User {} can't be invited to channel, make sure the email is associated to an Askdata user".format(follower_email))
 
-            headers = {
-                "Content-Type": "application/json",
-                "Authorization": "Bearer" + " " + self._token
-            }
-            query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-            #logging.info("URL {}".format(query_url))
-            r = s.post(url=url, json=body, headers=headers)
-            r.raise_for_status()
         else:
             logging.error("EMAIL ERRATA: Inserire una email corrispondente ad un utente Askdata")
 
